@@ -39,43 +39,43 @@ __all__ = (
     "ClusteringKeyTypeDef",
     "ColumnDefinitionTypeDef",
     "CommentTypeDef",
-    "CreateKeyspaceRequestRequestTypeDef",
-    "CreateKeyspaceResponseTypeDef",
-    "CreateTableRequestRequestTypeDef",
-    "CreateTableResponseTypeDef",
+    "TagTypeDef",
+    "ResponseMetadataTypeDef",
+    "EncryptionSpecificationTypeDef",
+    "PointInTimeRecoveryTypeDef",
+    "TimeToLiveTypeDef",
     "DeleteKeyspaceRequestRequestTypeDef",
     "DeleteTableRequestRequestTypeDef",
-    "EncryptionSpecificationTypeDef",
     "GetKeyspaceRequestRequestTypeDef",
-    "GetKeyspaceResponseTypeDef",
     "GetTableRequestRequestTypeDef",
-    "GetTableResponseTypeDef",
-    "KeyspaceSummaryTypeDef",
-    "ListKeyspacesRequestListKeyspacesPaginateTypeDef",
-    "ListKeyspacesRequestRequestTypeDef",
-    "ListKeyspacesResponseTypeDef",
-    "ListTablesRequestListTablesPaginateTypeDef",
-    "ListTablesRequestRequestTypeDef",
-    "ListTablesResponseTypeDef",
-    "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "PaginatorConfigTypeDef",
-    "PartitionKeyTypeDef",
     "PointInTimeRecoverySummaryTypeDef",
-    "PointInTimeRecoveryTypeDef",
-    "ResponseMetadataTypeDef",
-    "RestoreTableRequestRequestTypeDef",
-    "RestoreTableResponseTypeDef",
-    "SchemaDefinitionTypeDef",
-    "StaticColumnTypeDef",
+    "KeyspaceSummaryTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListKeyspacesRequestRequestTypeDef",
+    "ListTablesRequestRequestTypeDef",
     "TableSummaryTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "PartitionKeyTypeDef",
+    "StaticColumnTypeDef",
+    "CreateKeyspaceRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
-    "TimeToLiveTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateTableRequestRequestTypeDef",
+    "CreateKeyspaceResponseTypeDef",
+    "CreateTableResponseTypeDef",
+    "GetKeyspaceResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "RestoreTableResponseTypeDef",
     "UpdateTableResponseTypeDef",
+    "RestoreTableRequestRequestTypeDef",
+    "UpdateTableRequestRequestTypeDef",
+    "ListKeyspacesResponseTypeDef",
+    "ListKeyspacesRequestListKeyspacesPaginateTypeDef",
+    "ListTablesRequestListTablesPaginateTypeDef",
+    "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    "ListTablesResponseTypeDef",
+    "SchemaDefinitionTypeDef",
+    "CreateTableRequestRequestTypeDef",
+    "GetTableResponseTypeDef",
 )
 
 _RequiredCapacitySpecificationSummaryTypeDef = TypedDict(
@@ -146,84 +146,22 @@ CommentTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateKeyspaceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateKeyspaceRequestRequestTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "keyspaceName": str,
-    },
-)
-_OptionalCreateKeyspaceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateKeyspaceRequestRequestTypeDef",
-    {
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateKeyspaceRequestRequestTypeDef(
-    _RequiredCreateKeyspaceRequestRequestTypeDef, _OptionalCreateKeyspaceRequestRequestTypeDef
-):
-    pass
-
-
-CreateKeyspaceResponseTypeDef = TypedDict(
-    "CreateKeyspaceResponseTypeDef",
-    {
-        "resourceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "key": str,
+        "value": str,
     },
 )
 
-_RequiredCreateTableRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateTableRequestRequestTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "keyspaceName": str,
-        "tableName": str,
-        "schemaDefinition": "SchemaDefinitionTypeDef",
-    },
-)
-_OptionalCreateTableRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateTableRequestRequestTypeDef",
-    {
-        "comment": "CommentTypeDef",
-        "capacitySpecification": "CapacitySpecificationTypeDef",
-        "encryptionSpecification": "EncryptionSpecificationTypeDef",
-        "pointInTimeRecovery": "PointInTimeRecoveryTypeDef",
-        "ttl": "TimeToLiveTypeDef",
-        "defaultTimeToLive": int,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateTableRequestRequestTypeDef(
-    _RequiredCreateTableRequestRequestTypeDef, _OptionalCreateTableRequestRequestTypeDef
-):
-    pass
-
-
-CreateTableResponseTypeDef = TypedDict(
-    "CreateTableResponseTypeDef",
-    {
-        "resourceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteKeyspaceRequestRequestTypeDef = TypedDict(
-    "DeleteKeyspaceRequestRequestTypeDef",
-    {
-        "keyspaceName": str,
-    },
-)
-
-DeleteTableRequestRequestTypeDef = TypedDict(
-    "DeleteTableRequestRequestTypeDef",
-    {
-        "keyspaceName": str,
-        "tableName": str,
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -248,19 +186,39 @@ class EncryptionSpecificationTypeDef(
     pass
 
 
-GetKeyspaceRequestRequestTypeDef = TypedDict(
-    "GetKeyspaceRequestRequestTypeDef",
+PointInTimeRecoveryTypeDef = TypedDict(
+    "PointInTimeRecoveryTypeDef",
+    {
+        "status": PointInTimeRecoveryStatusType,
+    },
+)
+
+TimeToLiveTypeDef = TypedDict(
+    "TimeToLiveTypeDef",
+    {
+        "status": Literal["ENABLED"],
+    },
+)
+
+DeleteKeyspaceRequestRequestTypeDef = TypedDict(
+    "DeleteKeyspaceRequestRequestTypeDef",
     {
         "keyspaceName": str,
     },
 )
 
-GetKeyspaceResponseTypeDef = TypedDict(
-    "GetKeyspaceResponseTypeDef",
+DeleteTableRequestRequestTypeDef = TypedDict(
+    "DeleteTableRequestRequestTypeDef",
+    {
+        "keyspaceName": str,
+        "tableName": str,
+    },
+)
+
+GetKeyspaceRequestRequestTypeDef = TypedDict(
+    "GetKeyspaceRequestRequestTypeDef",
     {
         "keyspaceName": str,
-        "resourceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -272,183 +230,6 @@ GetTableRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetTableResponseTypeDef = TypedDict(
-    "GetTableResponseTypeDef",
-    {
-        "keyspaceName": str,
-        "tableName": str,
-        "resourceArn": str,
-        "creationTimestamp": datetime,
-        "status": TableStatusType,
-        "schemaDefinition": "SchemaDefinitionTypeDef",
-        "capacitySpecification": "CapacitySpecificationSummaryTypeDef",
-        "encryptionSpecification": "EncryptionSpecificationTypeDef",
-        "pointInTimeRecovery": "PointInTimeRecoverySummaryTypeDef",
-        "ttl": "TimeToLiveTypeDef",
-        "defaultTimeToLive": int,
-        "comment": "CommentTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-KeyspaceSummaryTypeDef = TypedDict(
-    "KeyspaceSummaryTypeDef",
-    {
-        "keyspaceName": str,
-        "resourceArn": str,
-    },
-)
-
-ListKeyspacesRequestListKeyspacesPaginateTypeDef = TypedDict(
-    "ListKeyspacesRequestListKeyspacesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListKeyspacesRequestRequestTypeDef = TypedDict(
-    "ListKeyspacesRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-ListKeyspacesResponseTypeDef = TypedDict(
-    "ListKeyspacesResponseTypeDef",
-    {
-        "nextToken": str,
-        "keyspaces": List["KeyspaceSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
-    "_RequiredListTablesRequestListTablesPaginateTypeDef",
-    {
-        "keyspaceName": str,
-    },
-)
-_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
-    "_OptionalListTablesRequestListTablesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListTablesRequestListTablesPaginateTypeDef(
-    _RequiredListTablesRequestListTablesPaginateTypeDef,
-    _OptionalListTablesRequestListTablesPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListTablesRequestRequestTypeDef = TypedDict(
-    "_RequiredListTablesRequestRequestTypeDef",
-    {
-        "keyspaceName": str,
-    },
-)
-_OptionalListTablesRequestRequestTypeDef = TypedDict(
-    "_OptionalListTablesRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-
-class ListTablesRequestRequestTypeDef(
-    _RequiredListTablesRequestRequestTypeDef, _OptionalListTablesRequestRequestTypeDef
-):
-    pass
-
-
-ListTablesResponseTypeDef = TypedDict(
-    "ListTablesResponseTypeDef",
-    {
-        "nextToken": str,
-        "tables": List["TableSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
-    "_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
-    {
-        "resourceArn": str,
-    },
-)
-_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
-    "_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListTagsForResourceRequestListTagsForResourcePaginateTypeDef(
-    _RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
-    _OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
-):
-    pass
-
-
-_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredListTagsForResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-    },
-)
-_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalListTagsForResourceRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-
-class ListTagsForResourceRequestRequestTypeDef(
-    _RequiredListTagsForResourceRequestRequestTypeDef,
-    _OptionalListTagsForResourceRequestRequestTypeDef,
-):
-    pass
-
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "nextToken": str,
-        "tags": List["TagTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-PartitionKeyTypeDef = TypedDict(
-    "PartitionKeyTypeDef",
-    {
-        "name": str,
-    },
-)
-
 _RequiredPointInTimeRecoverySummaryTypeDef = TypedDict(
     "_RequiredPointInTimeRecoverySummaryTypeDef",
     {
@@ -470,21 +251,185 @@ class PointInTimeRecoverySummaryTypeDef(
     pass
 
 
-PointInTimeRecoveryTypeDef = TypedDict(
-    "PointInTimeRecoveryTypeDef",
+KeyspaceSummaryTypeDef = TypedDict(
+    "KeyspaceSummaryTypeDef",
     {
-        "status": PointInTimeRecoveryStatusType,
+        "keyspaceName": str,
+        "resourceArn": str,
     },
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+ListKeyspacesRequestRequestTypeDef = TypedDict(
+    "ListKeyspacesRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+_RequiredListTablesRequestRequestTypeDef = TypedDict(
+    "_RequiredListTablesRequestRequestTypeDef",
+    {
+        "keyspaceName": str,
+    },
+)
+_OptionalListTablesRequestRequestTypeDef = TypedDict(
+    "_OptionalListTablesRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListTablesRequestRequestTypeDef(
+    _RequiredListTablesRequestRequestTypeDef, _OptionalListTablesRequestRequestTypeDef
+):
+    pass
+
+
+TableSummaryTypeDef = TypedDict(
+    "TableSummaryTypeDef",
+    {
+        "keyspaceName": str,
+        "tableName": str,
+        "resourceArn": str,
+    },
+)
+
+_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceRequestRequestTypeDef(
+    _RequiredListTagsForResourceRequestRequestTypeDef,
+    _OptionalListTagsForResourceRequestRequestTypeDef,
+):
+    pass
+
+
+PartitionKeyTypeDef = TypedDict(
+    "PartitionKeyTypeDef",
+    {
+        "name": str,
+    },
+)
+
+StaticColumnTypeDef = TypedDict(
+    "StaticColumnTypeDef",
+    {
+        "name": str,
+    },
+)
+
+_RequiredCreateKeyspaceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateKeyspaceRequestRequestTypeDef",
+    {
+        "keyspaceName": str,
+    },
+)
+_OptionalCreateKeyspaceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateKeyspaceRequestRequestTypeDef",
+    {
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateKeyspaceRequestRequestTypeDef(
+    _RequiredCreateKeyspaceRequestRequestTypeDef, _OptionalCreateKeyspaceRequestRequestTypeDef
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Sequence[TagTypeDef],
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateKeyspaceResponseTypeDef = TypedDict(
+    "CreateKeyspaceResponseTypeDef",
+    {
+        "resourceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateTableResponseTypeDef = TypedDict(
+    "CreateTableResponseTypeDef",
+    {
+        "resourceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetKeyspaceResponseTypeDef = TypedDict(
+    "GetKeyspaceResponseTypeDef",
+    {
+        "keyspaceName": str,
+        "resourceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "nextToken": str,
+        "tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RestoreTableResponseTypeDef = TypedDict(
+    "RestoreTableResponseTypeDef",
+    {
+        "restoredTableARN": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateTableResponseTypeDef = TypedDict(
+    "UpdateTableResponseTypeDef",
+    {
+        "resourceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
@@ -501,10 +446,10 @@ _OptionalRestoreTableRequestRequestTypeDef = TypedDict(
     "_OptionalRestoreTableRequestRequestTypeDef",
     {
         "restoreTimestamp": Union[datetime, str],
-        "capacitySpecificationOverride": "CapacitySpecificationTypeDef",
-        "encryptionSpecificationOverride": "EncryptionSpecificationTypeDef",
-        "pointInTimeRecoveryOverride": "PointInTimeRecoveryTypeDef",
-        "tagsOverride": Sequence["TagTypeDef"],
+        "capacitySpecificationOverride": CapacitySpecificationTypeDef,
+        "encryptionSpecificationOverride": EncryptionSpecificationTypeDef,
+        "pointInTimeRecoveryOverride": PointInTimeRecoveryTypeDef,
+        "tagsOverride": Sequence[TagTypeDef],
     },
     total=False,
 )
@@ -516,82 +461,6 @@ class RestoreTableRequestRequestTypeDef(
     pass
 
 
-RestoreTableResponseTypeDef = TypedDict(
-    "RestoreTableResponseTypeDef",
-    {
-        "restoredTableARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredSchemaDefinitionTypeDef = TypedDict(
-    "_RequiredSchemaDefinitionTypeDef",
-    {
-        "allColumns": Sequence["ColumnDefinitionTypeDef"],
-        "partitionKeys": Sequence["PartitionKeyTypeDef"],
-    },
-)
-_OptionalSchemaDefinitionTypeDef = TypedDict(
-    "_OptionalSchemaDefinitionTypeDef",
-    {
-        "clusteringKeys": Sequence["ClusteringKeyTypeDef"],
-        "staticColumns": Sequence["StaticColumnTypeDef"],
-    },
-    total=False,
-)
-
-
-class SchemaDefinitionTypeDef(_RequiredSchemaDefinitionTypeDef, _OptionalSchemaDefinitionTypeDef):
-    pass
-
-
-StaticColumnTypeDef = TypedDict(
-    "StaticColumnTypeDef",
-    {
-        "name": str,
-    },
-)
-
-TableSummaryTypeDef = TypedDict(
-    "TableSummaryTypeDef",
-    {
-        "keyspaceName": str,
-        "tableName": str,
-        "resourceArn": str,
-    },
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-)
-
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "key": str,
-        "value": str,
-    },
-)
-
-TimeToLiveTypeDef = TypedDict(
-    "TimeToLiveTypeDef",
-    {
-        "status": Literal["ENABLED"],
-    },
-)
-
-UntagResourceRequestRequestTypeDef = TypedDict(
-    "UntagResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-)
-
 _RequiredUpdateTableRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateTableRequestRequestTypeDef",
     {
@@ -602,11 +471,11 @@ _RequiredUpdateTableRequestRequestTypeDef = TypedDict(
 _OptionalUpdateTableRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateTableRequestRequestTypeDef",
     {
-        "addColumns": Sequence["ColumnDefinitionTypeDef"],
-        "capacitySpecification": "CapacitySpecificationTypeDef",
-        "encryptionSpecification": "EncryptionSpecificationTypeDef",
-        "pointInTimeRecovery": "PointInTimeRecoveryTypeDef",
-        "ttl": "TimeToLiveTypeDef",
+        "addColumns": Sequence[ColumnDefinitionTypeDef],
+        "capacitySpecification": CapacitySpecificationTypeDef,
+        "encryptionSpecification": EncryptionSpecificationTypeDef,
+        "pointInTimeRecovery": PointInTimeRecoveryTypeDef,
+        "ttl": TimeToLiveTypeDef,
         "defaultTimeToLive": int,
     },
     total=False,
@@ -619,10 +488,141 @@ class UpdateTableRequestRequestTypeDef(
     pass
 
 
-UpdateTableResponseTypeDef = TypedDict(
-    "UpdateTableResponseTypeDef",
+ListKeyspacesResponseTypeDef = TypedDict(
+    "ListKeyspacesResponseTypeDef",
     {
+        "nextToken": str,
+        "keyspaces": List[KeyspaceSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListKeyspacesRequestListKeyspacesPaginateTypeDef = TypedDict(
+    "ListKeyspacesRequestListKeyspacesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_RequiredListTablesRequestListTablesPaginateTypeDef",
+    {
+        "keyspaceName": str,
+    },
+)
+_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_OptionalListTablesRequestListTablesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListTablesRequestListTablesPaginateTypeDef(
+    _RequiredListTablesRequestListTablesPaginateTypeDef,
+    _OptionalListTablesRequestListTablesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    {
         "resourceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceRequestListTagsForResourcePaginateTypeDef(
+    _RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+    _OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+):
+    pass
+
+
+ListTablesResponseTypeDef = TypedDict(
+    "ListTablesResponseTypeDef",
+    {
+        "nextToken": str,
+        "tables": List[TableSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredSchemaDefinitionTypeDef = TypedDict(
+    "_RequiredSchemaDefinitionTypeDef",
+    {
+        "allColumns": Sequence[ColumnDefinitionTypeDef],
+        "partitionKeys": Sequence[PartitionKeyTypeDef],
+    },
+)
+_OptionalSchemaDefinitionTypeDef = TypedDict(
+    "_OptionalSchemaDefinitionTypeDef",
+    {
+        "clusteringKeys": Sequence[ClusteringKeyTypeDef],
+        "staticColumns": Sequence[StaticColumnTypeDef],
+    },
+    total=False,
+)
+
+
+class SchemaDefinitionTypeDef(_RequiredSchemaDefinitionTypeDef, _OptionalSchemaDefinitionTypeDef):
+    pass
+
+
+_RequiredCreateTableRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateTableRequestRequestTypeDef",
+    {
+        "keyspaceName": str,
+        "tableName": str,
+        "schemaDefinition": SchemaDefinitionTypeDef,
+    },
+)
+_OptionalCreateTableRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateTableRequestRequestTypeDef",
+    {
+        "comment": CommentTypeDef,
+        "capacitySpecification": CapacitySpecificationTypeDef,
+        "encryptionSpecification": EncryptionSpecificationTypeDef,
+        "pointInTimeRecovery": PointInTimeRecoveryTypeDef,
+        "ttl": TimeToLiveTypeDef,
+        "defaultTimeToLive": int,
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateTableRequestRequestTypeDef(
+    _RequiredCreateTableRequestRequestTypeDef, _OptionalCreateTableRequestRequestTypeDef
+):
+    pass
+
+
+GetTableResponseTypeDef = TypedDict(
+    "GetTableResponseTypeDef",
+    {
+        "keyspaceName": str,
+        "tableName": str,
+        "resourceArn": str,
+        "creationTimestamp": datetime,
+        "status": TableStatusType,
+        "schemaDefinition": SchemaDefinitionTypeDef,
+        "capacitySpecification": CapacitySpecificationSummaryTypeDef,
+        "encryptionSpecification": EncryptionSpecificationTypeDef,
+        "pointInTimeRecovery": PointInTimeRecoverySummaryTypeDef,
+        "ttl": TimeToLiveTypeDef,
+        "defaultTimeToLive": int,
+        "comment": CommentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
